@@ -1,7 +1,6 @@
 """
 Classes for querying which lines have changed based on a diff.
 """
-from __future__ import unicode_literals
 from abc import ABCMeta, abstractmethod
 from diff_cover.git_diff import GitDiffError
 import fnmatch
@@ -9,7 +8,7 @@ import os
 import re
 
 
-class BaseDiffReporter(object):
+class BaseDiffReporter:
     """
     Query information about lines changed in a diff.
     """
@@ -96,10 +95,15 @@ class GitDiffReporter(BaseDiffReporter):
     Query information from a Git diff between branches.
     """
 
-    def __init__(self, compare_branch='origin/master', git_diff=None,
-                 ignore_staged=None, ignore_unstaged=None,
-                 supported_extensions=None,
-                 exclude=None):
+    def __init__(
+        self,
+        compare_branch="origin/master",
+        git_diff=None,
+        ignore_staged=None,
+        ignore_unstaged=None,
+        supported_extensions=None,
+        exclude=None,
+    ):
         """
         Configure the reporter to use `git_diff` as the wrapper
         for the `git diff` tool.  (Should have same interface
@@ -112,7 +116,7 @@ class GitDiffReporter(BaseDiffReporter):
             options.append("unstaged")
 
         # Branch is always present, so use as basis for name
-        name = "{0}...HEAD".format(compare_branch)
+        name = f"{compare_branch}...HEAD"
         if len(options) > 0:
             # If more options are present separate them by comma's, except the last one
             for item in options[:-1]:
@@ -120,7 +124,7 @@ class GitDiffReporter(BaseDiffReporter):
             # Apply and + changes to the last option
             name += " and " + options[-1] + " changes"
 
-        super(GitDiffReporter, self).__init__(name, exclude)
+        super().__init__(name, exclude)
 
         self._compare_branch = compare_branch
         self._git_diff_tool = git_diff
@@ -204,13 +208,17 @@ class GitDiffReporter(BaseDiffReporter):
                     root, extension = os.path.splitext(src_path)
                     extension = extension[1:].lower()
                     # 'not self._supported_extensions' tests for both None and empty list []
-                    if not self._supported_extensions or extension in self._supported_extensions:
+                    if (
+                        not self._supported_extensions
+                        or extension in self._supported_extensions
+                    ):
                         added_lines, deleted_lines = diff_dict[src_path]
 
                         # Remove any lines from the dict that have been deleted
                         # Include any lines that have been added
                         result_dict[src_path] = [
-                            line for line in result_dict.get(src_path, [])
+                            line
+                            for line in result_dict.get(src_path, [])
                             if not line in deleted_lines
                         ] + added_lines
 
@@ -226,8 +234,8 @@ class GitDiffReporter(BaseDiffReporter):
 
     # Regular expressions used to parse the diff output
     SRC_FILE_RE = re.compile(r'^diff --git "?a/.*"? "?b/([^ \n"]*)"?')
-    MERGE_CONFLICT_RE = re.compile(r'^diff --cc ([^ \n]*)')
-    HUNK_LINE_RE = re.compile(r'\+([0-9]*)')
+    MERGE_CONFLICT_RE = re.compile(r"^diff --cc ([^ \n]*)")
+    HUNK_LINE_RE = re.compile(r"\+([0-9]*)")
 
     def _parse_diff_str(self, diff_str):
         """
@@ -275,12 +283,12 @@ class GitDiffReporter(BaseDiffReporter):
         found_hunk = False
 
         # Parse the diff string into sections by source file
-        for line in diff_str.split('\n'):
+        for line in diff_str.split("\n"):
 
             # If the line starts with "diff --git"
             # or "diff --cc" (in the case of a merge conflict)
             # then it is the start of a new source file
-            if line.startswith('diff --git') or line.startswith('diff --cc'):
+            if line.startswith("diff --git") or line.startswith("diff --cc"):
 
                 # Retrieve the name of the source file
                 src_path = self._parse_source_line(line)
@@ -299,7 +307,7 @@ class GitDiffReporter(BaseDiffReporter):
 
                 # Only add lines if we're in a hunk section
                 # (ignore index and files changed lines)
-                if found_hunk or line.startswith('@@'):
+                if found_hunk or line.startswith("@@"):
 
                     # Remember that we found a hunk
                     found_hunk = True
@@ -311,7 +319,7 @@ class GitDiffReporter(BaseDiffReporter):
                         # We tolerate other information before we have
                         # a source file defined, unless it's a hunk line
                         if line.startswith("@@"):
-                            msg = "Hunk has no source file: '{0}'".format(line)
+                            msg = f"Hunk has no source file: '{line}'"
                             raise GitDiffError(msg)
 
         return source_dict
@@ -337,12 +345,12 @@ class GitDiffReporter(BaseDiffReporter):
 
             # If this is the start of the hunk definition, retrieve
             # the starting line number
-            if line.startswith('@@'):
+            if line.startswith("@@"):
                 line_num = self._parse_hunk_line(line)
                 current_line_new, current_line_old = line_num, line_num
 
             # This is an added/modified line, so store the line number
-            elif line.startswith('+'):
+            elif line.startswith("+"):
 
                 # Since we parse for source file sections before
                 # calling this method, we're guaranteed to have a source
@@ -357,7 +365,7 @@ class GitDiffReporter(BaseDiffReporter):
 
             # This is a deleted line that does not exist in the final
             # version, so skip it
-            elif line.startswith('-'):
+            elif line.startswith("-"):
 
                 # Since we parse for source file sections before
                 # calling this method, we're guaranteed to have a source
@@ -391,12 +399,12 @@ class GitDiffReporter(BaseDiffReporter):
         Given a source line in `git diff` output, return the path
         to the source file.
         """
-        if '--git' in line:
+        if "--git" in line:
             regex = self.SRC_FILE_RE
-        elif '--cc' in line:
+        elif "--cc" in line:
             regex = self.MERGE_CONFLICT_RE
         else:
-            msg = "Do not recognize format of source in line '{0}'".format(line)
+            msg = f"Do not recognize format of source in line '{line}'"
             raise GitDiffError(msg)
 
         # Parse for the source file path
@@ -406,7 +414,7 @@ class GitDiffReporter(BaseDiffReporter):
             return groups[0]
 
         else:
-            msg = "Could not parse source path in line '{0}'".format(line)
+            msg = f"Could not parse source path in line '{line}'"
             raise GitDiffError(msg)
 
     def _parse_hunk_line(self, line):
@@ -426,7 +434,7 @@ class GitDiffReporter(BaseDiffReporter):
         in the `TEXT` section of the line.
         """
         # Split the line at the @@ terminators (start and end of the line)
-        components = line.split('@@')
+        components = line.split("@@")
 
         # The first component should be an empty string, because
         # the line starts with '@@'.  The second component should
@@ -443,15 +451,15 @@ class GitDiffReporter(BaseDiffReporter):
                     return int(groups[0])
 
                 except ValueError:
-                    msg = "Could not parse '{0}' as a line number".format(groups[0])
+                    msg = "Could not parse '{}' as a line number".format(groups[0])
                     raise GitDiffError(msg)
 
             else:
-                msg = "Could not find start of hunk in line '{0}'".format(line)
+                msg = f"Could not find start of hunk in line '{line}'"
                 raise GitDiffError(msg)
 
         else:
-            msg = "Could not parse hunk in line '{0}'".format(line)
+            msg = f"Could not parse hunk in line '{line}'"
             raise GitDiffError(msg)
 
     @staticmethod
